#!/usr/bin/env python

# desat_col_cast.py
# 
# A script to desaturate and image and add a layer of total black & white
# at reduced opacity to make the image more stark.
# Also to add a colour cast layer which leaves black parts of the image
# unchanged.
# 
#
# License: GPLv3
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY# without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# To view a copy of the GNU General Public License
# visit: http://www.gnu.org/licenses/gpl.html
#
#
# ------------
#| Change Log |
# ------------
# Rel 1: Initial release.
# Rel 2: DM 27 November 2019.
# Rel 3: DM 30 November 2019 - to correctly use greyscale images.
#import Image
from gimpfu import *
def python_desat_col_cast(image, layer) :
	pdb.gimp_image_undo_group_start(image)
	pdb.gimp_context_push()

	base_type = pdb.gimp_image_base_type(image)					#check if RGB or GRAY

	if base_type == GRAY:

		pdb.gimp_image_convert_rgb(image)					#if greyscale image convert to RGB
		Desaturate = pdb.gimp_layer_new_from_drawable(layer,image)		#make new layer to be named "Desaturate" (source, destination)
		pdb.gimp_image_insert_layer(image,Desaturate,None,0)			#(image, layer, parent, position)
		pdb.gimp_item_set_name(Desaturate,"Desaturate")				#name the layer
	else:
	
		Desaturate = pdb.gimp_layer_new_from_drawable(layer,image)		#make new layer to be named "Desaturate" (source, destination)
		pdb.gimp_image_insert_layer(image,Desaturate,None,0)			#(image, layer, parent, position)
		pdb.gimp_drawable_desaturate(Desaturate,DESATURATE_LUMINANCE)		#(drawable, destination)
		pdb.gimp_item_set_name(Desaturate,"Desaturate")				#name the layer
					
	Threshold = pdb.gimp_layer_new_from_drawable(Desaturate,image)			#copy "Desaturate" to Threshold (source, destination)
	pdb.gimp_image_insert_layer(image,Threshold,None,0)				#(image, layer, parent, position)
	pdb.gimp_item_set_name(Threshold,"Threshold")					#name the layer
			
	Colcast = pdb.gimp_layer_new_from_drawable(Threshold,image)			#copy "Threshold" to Colcast (source, destination)
	pdb.gimp_image_insert_layer(image,Colcast,None,0)				#(image, layer, parent, position)
	pdb.gimp_item_set_name(Colcast,"Colcast")					#name the layer
			
	Colour = pdb.gimp_layer_new_from_drawable(Colcast,image)			#copy "Colcast" to Colour (source, destination)
	pdb.gimp_image_insert_layer(image,Colour,None,0)				#(image, layer, parent, position)
	pdb.gimp_item_set_name(Colour,"Colour")						#name the layer
			
	pdb.gimp_drawable_edit_fill(Colour, FILL_FOREGROUND)				#add existing foreground colour
	pdb.gimp_layer_set_mode(Colour, LAYER_MODE_OVERLAY)				#change Colour layer to overlay mode
	pdb.gimp_drawable_invert(Colour, FALSE)						#invert Colour of colour layer

	pdb.gimp_drawable_invert(Colcast, FALSE)					#invert Colcast layer

	Colcast = pdb.gimp_image_merge_down(image, Colour, EXPAND_AS_NECESSARY)		#merge Colour into Colcast layer

	pdb.gimp_drawable_invert(Colcast, FALSE)					#re-invert Colcast layer
	pdb.gimp_layer_set_opacity(Colcast, 50.0)					#set opacity at 50%

	pdb.gimp_layer_set_mode(Threshold, LAYER_MODE_OVERLAY)				#change Threshold layer to overlay mode
	pdb.gimp_layer_set_opacity(Threshold, 50.0)					#set opacity at 50%

	pdb.gimp_layer_set_mode(Colcast, LAYER_MODE_OVERLAY)				#change Colcast layer to overlay mode

	pdb.gimp_selection_none(image)

	pdb.gimp_context_pop()
	pdb.gimp_image_undo_group_end(image)
	pdb.gimp_displays_flush()


register(
	"python_fu_desat_col_cast",
	"Create Black & White Image with Colour-cast",
	"Create Black & White Image with Colour-cast",
	"David Marsden",
	"David Marsden",
	"November 2019",
	"<Image>/Python-Fu/Desat with Colour Cast...",             #Menu path
	"RGB*, GRAY*", 
	[],
	[],
	python_desat_col_cast)

main()
